@@ -23,6 +23,7 @@ mod detail {
     use crate::{
         data_type::DataType,
         definitions::{N_NODES_ON_STACK, N_UNARYOPS_OF_DEEPEX_ON_STACK},
+        format_exerr,
         operators::UnaryOp,
         parser::{self, Paren, ParsedToken},
         BinOp, ExError, ExResult, FlatEx, MakeOperators, MatchLiteral, Operator,
@@ -74,13 +75,11 @@ mod detail {
         n_unique_vars: usize,
     ) -> ExResult<T> {
         if n_unique_vars != vars.len() {
-            return Err(ExError {
-                msg: format!(
-                    "parsed expression contains {} vars but passed slice has {} elements",
-                    n_unique_vars,
-                    vars.len()
-                ),
-            });
+            return Err(format_exerr!(
+                "parsed expression contains {} vars but passed slice has {} elements",
+                n_unique_vars,
+                vars.len()
+            ));
         }
         let mut numbers = nodes
             .iter()
@@ -596,11 +595,11 @@ pub fn flatten_vecs<T: Clone + Debug>(
             };
             low_prio_op
                 .unary_op
-                .append_after(&deep_expr.unary_op().op.clone());
+                .append_after(deep_expr.unary_op().op.clone());
         } else {
             flat_nodes[0]
                 .unary_op
-                .append_after(&deep_expr.unary_op().op.clone());
+                .append_after(deep_expr.unary_op().op.clone());
         }
     }
     (flat_nodes, flat_ops)
