@@ -1,4 +1,4 @@
-#![doc(html_root_url = "https://docs.rs/exmex/0.14.0")]
+#![doc(html_root_url = "https://docs.rs/exmex/0.15.0")]
 //! Exmex is an extendable mathematical expression parser and evaluator. Ease of use, flexibility, and efficient evaluations are its main design goals.
 //! Exmex can parse mathematical expressions possibly containing variables and operators. On the one hand, it comes with a list of default operators
 //! for floating point values. For differentiable default operators, Exmex can compute partial derivatives. On the other hand, users can define their
@@ -17,8 +17,8 @@
 //! # }
 //! ```
 //! For floats, we have a list of predifined operators containing
-//! `^`, `*`, `/`, `+`, `-`, `sin`, `cos`, `tan`, `exp`, `log`, and `log2`. Further, the constants π
-//! and Euler's number can be used via `π`/`PI` and `E`, respectively. The full list is
+//! `^`, `*`, `/`, `+`, `-`, `sin`, `cos`, `tan`, `exp`, `log`, and `log2`. Further, the constants π, τ,
+//! and Euler's number are refered to via `π`/`PI`, `τ/TAU`, and `E`, respectively. The full list is
 //! defined in [`FloatOpsFactory`](FloatOpsFactory). Library users can also create their
 //! own operators and constants as shown below in the section about extendability.
 //!
@@ -71,16 +71,16 @@
 //! [dependencies]
 //! exmex = { ..., features = ["partial", "serde", "value"] }
 //! ```
-//! 
-//! `partial` allows the computation of partal derivatives, `serde` enables serialization and 
+//!
+//! `partial` allows the computation of partal derivatives, `serde` enables serialization and
 //! deserialization, and `value` makes a more general value type accessible.
-//! 
+//!
 //! ### Partial Derivatives
 //!
-//! Expressions with floating point data types can be transformed into their 
+//! Expressions with floating point data types can be transformed into their
 //! partial derivatives again represented by expressions after activating the feature `partial`.
 //! See the [readme](https://github.com/bertiqwerty/exmex#partial-differentiation) for examples.
-//! 
+//!
 //! ### Serialization and Deserialization
 //!
 //! To use [`serde`](https://serde.rs/) you can activate the feature `serde`.
@@ -110,7 +110,7 @@
 //! * binary as well as unary such as `-`, or
 //! * constant such as `PI`.
 //!
-//! An operator's representation is defined in the field
+//! An operator's representation can be accessed via the method
 //! [`repr`](Operator::repr). A token of the string-to-be-parsed is identified as operator if it matches the operator's
 //! representation exactly. For instance, `PI` will be parsed as the constant π while `PI5` will be parsed as a variable with name `PI5`.
 //! When an operator's representation is used in a string-to-be-parsed, the following applies:
@@ -288,10 +288,7 @@ mod result;
 mod util;
 
 pub use {
-    expression::{
-        flat::FlatEx,
-        Express, MatchLiteral, NumberMatcher,
-    },
+    expression::{flat::FlatEx, Express, MatchLiteral, NumberMatcher},
     operators::{BinOp, FloatOpsFactory, MakeOperators, Operator},
     result::{ExError, ExResult},
 };
@@ -299,27 +296,24 @@ pub use {
 #[cfg(feature = "value")]
 mod value;
 #[cfg(feature = "value")]
-pub use value::{
-    parse_val, FlatExVal, Val, ValMatcher,
-    ValOpsFactory,
-};
+pub use value::{parse_val, FlatExVal, Val, ValMatcher, ValOpsFactory};
 #[cfg(feature = "partial")]
 mod partial;
 #[cfg(feature = "partial")]
 pub use partial::Differentiate;
 
 /// Exmex' prelude can be imported via can `use exmex::prelude::*;`.
-/// 
+///
 /// The prelude contains
-/// * expression trait [`Express`](Express), 
+/// * expression trait [`Express`](Express),
 /// * its implementation [`FlatEx`](FlatEx),
-/// * and the partial differentiation of [`FlatEx`](FlatEx), if the feature `partial` is active. 
-/// 
+/// * and the partial differentiation of [`FlatEx`](FlatEx), if the feature `partial` is active.
+///
 pub mod prelude {
     pub use crate::expression::{flat::FlatEx, Express};
-    pub use std::str::FromStr;
     #[cfg(feature = "partial")]
     pub use crate::Differentiate;
+    pub use std::str::FromStr;
 }
 
 /// Parses a string, evaluates the expression, and returns the resulting number.
@@ -335,9 +329,10 @@ where
 {
     let flatex = FlatEx::<T>::from_str_wo_compile(text)?;
     if !flatex.var_names().is_empty() {
-        return Err(ExError {
-            msg: format!("input string contains variables, '{}' ", text),
-        });
+        return Err(format_exerr!(
+            "input string contains variables, '{}' ",
+            text
+        ));
     }
     flatex.eval(&[])
 }
