@@ -109,9 +109,7 @@ where
 }
 
 fn map_parse_err<E: Debug>(e: E) -> ExError {
-    ExError {
-        msg: format!("{:?}", e),
-    }
+    format_exerr!("{:?}", e)
 }
 
 impl<I, F> FromStr for Val<I, F>
@@ -133,9 +131,7 @@ where
         });
         match res {
             Result::Ok(_) => res,
-            Result::Err(e) => Err(ExError {
-                msg: format!("could not parse {}, {:?}", s, e),
-            }),
+            Result::Err(e) => Err(format_exerr!("could not parse {}, {:?}", s, e)),
         }
     }
 }
@@ -658,6 +654,8 @@ where
             Operator::make_constant("PI", Val::Float(F::from(std::f64::consts::PI).unwrap())),
             Operator::make_constant("π", Val::Float(F::from(std::f64::consts::PI).unwrap())),
             Operator::make_constant("E", Val::Float(F::from(std::f64::consts::E).unwrap())),
+            Operator::make_constant("TAU", Val::Float(F::from(std::f64::consts::TAU).unwrap())),
+            Operator::make_constant("τ", Val::Float(F::from(std::f64::consts::TAU).unwrap())),
         ]
     }
 }
@@ -691,4 +689,3 @@ where
 {
     FlatEx::<Val<I, F>, ValOpsFactory<I, F>, ValMatcher>::from_str(text)
 }
-
