@@ -1,5 +1,6 @@
 #[cfg(test)]
 mod utils;
+use exmex::format_exerr;
 #[cfg(test)]
 use exmex::{
     eval_str, literal_matcher_from_pattern, ops_factory, parse,
@@ -80,11 +81,11 @@ fn test_flatex() -> ExResult<()> {
 }
 
 #[test]
-fn test_readme() {
+fn test_readme() -> ExResult<()> {
     fn readme() -> ExResult<()> {
-        let result = eval_str::<f64>("sin(73)")?;
-        assert!((result - 73f64.sin()).abs() < 1e-12);
-        let expr = parse::<f64>("2*β^3-4/τ")?;
+        let result = eval_str::<f64>("E^(2*π-τ)")?;
+        assert!((result - 1.0).abs() < 1e-12);
+        let expr = parse::<f64>("2*x^3-4/y")?;
         let result = expr.eval(&[5.3, 0.5])?;
         assert!((result - 289.75399999999996).abs() < 1e-12);
         Ok(())
@@ -108,8 +109,9 @@ fn test_readme() {
         assert_eq!(result, u32::MAX - 1);
         Ok(())
     }
-    assert!(!readme().is_err());
-    assert!(!readme_int().is_err());
+    readme()?;
+    readme_int()?;
+    Ok(())
 }
 #[test]
 fn test_variables_curly_space_names() -> ExResult<()> {
@@ -186,9 +188,7 @@ fn test_variables_non_ascii() -> ExResult<()> {
             } else if s == "👎" {
                 Ok(Self { val: false })
             } else {
-                Err(Self::Err {
-                    msg: format!("cannot parse {} to `Thumbs`", s),
-                })
+                Err(format_exerr!("cannot parse {} to `Thumbs`", s))
             }
         }
     }
@@ -386,7 +386,7 @@ fn test_custom_ops() -> ExResult<()> {
     }
     let expr = FlatEx::<f32, SomeF32Operators>::from_str("2**2*invert(3)")?;
     let val = expr.eval(&[])?;
-    utils::assert_float_eq::<f32>(val, 4.0 / 3.0,  1e-6, 0.0, "");
+    utils::assert_float_eq::<f32>(val, 4.0 / 3.0, 1e-6, 0.0, "");
 
     #[derive(Clone)]
     struct ExtendedF32Operators;
@@ -410,7 +410,7 @@ fn test_custom_ops() -> ExResult<()> {
     }
     let expr = FlatEx::<f32, ExtendedF32Operators>::from_str("2^2*1/(berti) + zer0(4)")?;
     let val = expr.eval(&[4.0])?;
-    utils::assert_float_eq::<f32>(val, 1.0,  1e-6, 0.0, "");
+    utils::assert_float_eq::<f32>(val, 1.0, 1e-6, 0.0, "");
     Ok(())
 }
 
@@ -428,6 +428,14 @@ fn test_eval_str() -> ExResult<()> {
     test("signum(-22/2)", -1.0)?;
     test("cbrt(8)", 2.0)?;
     test("2*3^2", 18.0)?;
+    test("PI", std::f64::consts::PI)?;
+    test("π", std::f64::consts::PI)?;
+    test("TAU", std::f64::consts::TAU)?;
+    test("τ", std::f64::consts::TAU)?;
+    test("τ", std::f64::consts::PI * 2.0)?;
+    test("E", std::f64::consts::E)?;
+    test("cos(TAU)", 1.0)?;
+    test("sin(τ)", 0.0)?;
     test("cos(PI/2)", 0.0)?;
     test("cos(π/2)", 0.0)?;
     test("-3^2", 9.0)?;
