@@ -9,15 +9,10 @@ pub fn assert_float_eq<T: num::Float + std::fmt::Display>(
     println!("d   {}", (f1 - f2).abs());
     if (f1 - f2).abs() >= atol + rtol * f2.abs() {
         println!("Floats not almost equal. {}\nf1: {}\nf2: {}\n", msg, f1, f2);
-        assert!(false);
+        unreachable!();
     }
 }
 
-#[cfg(test)]
-pub fn assert_float_eq_f32(f1: f32, f2: f32) {
-    assert_float_eq(f1, f2, 1e-6, 0.0, "");
-}
-
 #[cfg(test)]
 pub fn assert_float_eq_f64(f1: f64, f2: f64) {
     assert_float_eq(f1, f2, 1e-12, 0.0, "");
